@@ -73,7 +73,11 @@ KWaveSetup::KWaveSetup( QWidget *parent)
 	readSettings();
 
 	preview->setFixedSize( 220, 170 );
-	preview->setBackgroundColor( Qt::black );
+
+        QPalette palette;
+        palette.setColor( preview->backgroundRole(), Qt::black );
+        preview->setPalette( palette );
+
 	preview->show();    // otherwise saver does not get correct size
 	saver = new KWaveSaver( preview->winId() );
 
@@ -125,9 +129,13 @@ KWaveSaver::KWaveSaver( WId id ) : KScreenSaver( id )
 	readSettings();
 
 	timer = new QTimer( this );
-    	timer->start( 50, true );
-	setBackgroundColor( Qt::black );
-        erase();
+        timer->setSingleShot( true );
+	timer->start( 50 );
+        {
+            QPalette palette;
+            palette.setColor( backgroundRole(), Qt::black );
+            setPalette( palette );
+        }
 	wave = new Wave();
 	embed(wave);
 	wave->show();
@@ -152,7 +160,7 @@ void KWaveSaver::blank()
 	// Play wave
 
 	wave->updateGL();
-	timer->start( 100, true );
+	timer->start( 100 );
 
 }
 Wave::Wave( QWidget * parent ) : QGLWidget (parent)
@@ -309,7 +317,7 @@ bool Wave::LoadGLTextures()
         }
         else
         {
-                QImage dummy( 64, 64, 64 );
+                QImage dummy( 64, 64, QImage::Format_RGB32 );
                 dummy.fill( Qt::white );
                 buf = dummy;
                 tex = convertToGLFormat( buf );
