@@ -40,7 +40,7 @@
 #include <X11/Xos.h>
 #include <X11/Xresource.h>
 
-// added for kscreensave
+// added for kscreensaver
 void initXLock( GC gc );
 
 
@@ -62,6 +62,10 @@ void initXLock( GC gc );
 #define ICONW             64
 #define ICONH             64
 
+#ifndef min
+#define min(a,b) ((a)<(b)?(a):(b))
+#endif
+
 #if defined VMS || defined __QNX__
 #ifdef VMS
 /*#define VMS_PLAY*/
