@@ -24,6 +24,8 @@
 #define RISC_OS_CLOSE_BUTTON_H
 
 #include "Button.h"
+//Added by qt3to4:
+#include <QMouseEvent>
 
 namespace RiscOS
 {
