@@ -1,6 +1,6 @@
 /*
   RISC OS KWin client
-  
+
   Copyright 2000
     Rik Hemsley <rik@kde.org>
 
@@ -24,6 +24,8 @@
 #define RISC_OS_MAXIMISE_BUTTON_H
 
 #include "Button.h"
+//Added by qt3to4:
+#include <QMouseEvent>
 
 namespace RiscOS
 {
@@ -42,7 +44,7 @@ class MaximiseButton : public Button
 
    signals:
 
-      void maximizeClicked(ButtonState);
+      void maximizeClicked(Qt::MouseButton);
 
    protected:
 
